==> iggy-0.6.0-incubating-src.tar.gz: iggy-0.6.0-incubating-src/foreign/java/java-sdk/src/main/java/org/apache/iggy/client/blocking/tcp/PersonalAccessTokensTcpClient.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iggy.client.blocking.tcp;

import io.netty.buffer.Unpooled;
import org.apache.iggy.client.blocking.PersonalAccessTokensClient;
import org.apache.iggy.personalaccesstoken.PersonalAccessTokenInfo;
import org.apache.iggy.personalaccesstoken.RawPersonalAccessToken;
import org.apache.iggy.user.IdentityInfo;

import java.math.BigInteger;
import java.util.List;
import java.util.Optional;

import static org.apache.iggy.client.blocking.tcp.BytesSerializer.nameToBytes;
import static org.apache.iggy.client.blocking.tcp.BytesSerializer.toBytesAsU64;

class PersonalAccessTokensTcpClient implements PersonalAccessTokensClient {

    private final InternalTcpClient tcpClient;

    public PersonalAccessTokensTcpClient(InternalTcpClient tcpClient) {
        this.tcpClient = tcpClient;
    }

    @Override
    public RawPersonalAccessToken createPersonalAccessToken(String name, BigInteger expiry) {
        var payload = Unpooled.buffer();
        payload.writeBytes(nameToBytes(name));
        payload.writeBytes(toBytesAsU64(expiry));
        return tcpClient.exchangeForEntity(
                CommandCode.PersonalAccessToken.CREATE, payload, BytesDeserializer::readRawPersonalAccessToken);
    }

    @Override
    public List<PersonalAccessTokenInfo> getPersonalAccessTokens() {
        return tcpClient.exchangeForList(
                CommandCode.PersonalAccessToken.GET_ALL, BytesDeserializer::readPersonalAccessTokenInfo);
    }

    @Override
    public void deletePersonalAccessToken(String name) {
        var payload = nameToBytes(name);
        tcpClient.send(CommandCode.PersonalAccessToken.DELETE, payload);
    }

    @Override
    public IdentityInfo loginWithPersonalAccessToken(String token) {
        var payload = nameToBytes(token);
        return tcpClient.exchangeForEntity(CommandCode.PersonalAccessToken.LOGIN, payload, buf -> {
            var userId = buf.readUnsignedIntLE();
            return new IdentityInfo(userId, Optional.empty());
        });
    }
}

==> iggy-0.7.0-incubating-src.tar.gz: iggy-0.7.0-incubating-src/foreign/java/java-sdk/src/main/java/org/apache/iggy/client/blocking/tcp/PersonalAccessTokensTcpClient.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iggy.client.blocking.tcp;

import io.netty.buffer.Unpooled;
import org.apache.iggy.client.blocking.PersonalAccessTokensClient;
import org.apache.iggy.personalaccesstoken.PersonalAccessTokenInfo;
import org.apache.iggy.personalaccesstoken.RawPersonalAccessToken;
import org.apache.iggy.serde.BytesDeserializer;
import org.apache.iggy.serde.CommandCode;
import org.apache.iggy.user.IdentityInfo;

import java.math.BigInteger;
import java.util.List;
import java.util.Optional;

import static org.apache.iggy.serde.BytesSerializer.toBytes;
import static org.apache.iggy.serde.BytesSerializer.toBytesAsU64;

class PersonalAccessTokensTcpClient implements PersonalAccessTokensClient {

    private final InternalTcpClient tcpClient;

    public PersonalAccessTokensTcpClient(InternalTcpClient tcpClient) {
        this.tcpClient = tcpClient;
    }

    @Override
    public RawPersonalAccessToken createPersonalAccessToken(String name, BigInteger expiry) {
        var payload = Unpooled.buffer();
        payload.writeBytes(toBytes(name));
        payload.writeBytes(toBytesAsU64(expiry));
        return tcpClient.exchangeForEntity(
                CommandCode.PersonalAccessToken.CREATE, payload, BytesDeserializer::readRawPersonalAccessToken);
    }

    @Override
    public List<PersonalAccessTokenInfo> getPersonalAccessTokens() {
        return tcpClient.exchangeForList(
                CommandCode.PersonalAccessToken.GET_ALL, BytesDeserializer::readPersonalAccessTokenInfo);
    }

    @Override
    public void deletePersonalAccessToken(String name) {
        var payload = toBytes(name);
        tcpClient.send(CommandCode.PersonalAccessToken.DELETE, payload);
    }

    @Override
    public IdentityInfo loginWithPersonalAccessToken(String token) {
        var payload = toBytes(token);
        return tcpClient.exchangeForEntity(CommandCode.PersonalAccessToken.LOGIN, payload, buf -> {
            var userId = buf.readUnsignedIntLE();
            return new IdentityInfo(userId, Optional.empty());
        });
    }
}
